## Filters

Settings that filter the data returned by COSMIC simulations

### `binary_state`

Filter for the final state of the binaries you wish to retain

Default: [0, 1]

0
1
2
Option details

Each binary system will end its evolution in one of three states. Use these options to retain only certain endstates.

- `0`: Retain only binaries still alive today
- `1`: Retains binaries that merged
- `2`: Retains binaries that were disrupted

### `timestep_conditions`

Pick specific time resolutions to print at targeted stages of the binary evolution.

Default: dtp=None

Option details

This is used in conjunction with the [bse] section value dtp to determine the timestep resolution for printing to the bcm array. See the related guide for more information.

- `'dtp=None'`: Only the final time step is printed to the bcm array
- `'dtp=1.0'`: Use 1 Myr timesteps for all evolutionary stages
- `[['binstate==0', 'dtp=1.0']]`: Use 1 Myr timesteps for binaries until they merge or disrupt